# -*- rpm-spec -*-


%define with_guestfs               0
%define stable_defaults            0
%define askpass_package            "openssh-askpass"
%define qemu_user                  "qemu"
%define libvirt_packages           "libvirt-daemon-kvm,libvirt-daemon-config-network"
%define kvm_packages               ""
%define preferred_distros          "fedora,rhel"
%define default_hvs                "qemu,xen,lxc"

%if 0%{?rhel}
%define preferred_distros          "rhel,fedora"
%define kvm_packages               "qemu-kvm"
%define stable_defaults            1
%endif


# End local config

Name: virt-manager
Version: 1.2.1
Release: 1%{?dist}.12
%define verrel %{version}-%{release}

Summary: Virtual Machine Manager
Group: Applications/Emulators
License: GPLv2+
URL: http://virt-manager.org/
Source0: http://virt-manager.org/download/sources/%{name}/%{name}-%{version}.tar.gz


Patch0:	0001-add-cpu-selection.patch
Patch1:	0002-add-defaut-kernel-cmd-line.patch
Patch2:	0003-add-defaults-graphics-device-for-mips.patch
Patch3:	0004-modify-watchdog-default-action-to-poweroff.patch
Patch4:	0005-modify-disk-default-cache-mode.patch
Patch5:	0006-implement-of-modify-disk-default-cache-mode.patch
Patch6: 0007-Add-loongson3a-uefi-support-should-used-with-libvirt.patch	
Patch7: 0008-Use-default-scsi-bus-for-CD-ROM-iso-install-and.patch	

Patch8: 0001-Add-default-usbtablet-and-usbkeyboard-support.patch
Patch9:	0001-use-default-disk-cache-mode.patch
Patch10:	0001-Use-the-host-model-as-the-default-cpu-model.patch

BuildArch: noarch


Requires: virt-manager-common = %{verrel}
Requires: pygobject3
Requires: gtk3
Requires: libvirt-glib >= 0.0.9
Requires: libxml2-python
Requires: vte3
Requires: dconf
Requires: dbus-x11

# For console widget
Requires: gtk-vnc2
Requires: spice-gtk3

%if 0%{?rhel} == 7
Requires: gnome-icon-theme
%endif


BuildRequires: python
BuildRequires: intltool
BuildRequires: /usr/bin/pod2man


%description
Virtual Machine Manager provides a graphical tool for administering virtual
machines for KVM, Xen, and LXC. Start, stop, add or remove virtual devices,
connect to a graphical or serial console, and see resource usage statistics
for existing VMs on local or remote machines. Uses libvirt as the backend
management API.


%package common
Summary: Common files used by the different Virtual Machine Manager interfaces
Group: Applications/Emulators

# This version not strictly required: virt-manager should work with older,
# however varying amounts of functionality will not be enabled.
Requires: libvirt-python >= 0.7.0
Requires: libxml2-python
Requires: python-urlgrabber
Requires: python-ipaddr
Requires: libosinfo >= 0.2.10
# Required for gobject-introspection infrastructure
Requires: pygobject3-base

%description common
Common files used by the different virt-manager interfaces, as well as
virt-install related tools.


%package -n virt-install
Summary: Utilities for installing virtual machines

Requires: virt-manager-common = %{verrel}

Provides: virt-install
Provides: virt-clone
Provides: virt-convert
Provides: virt-xml
Obsoletes: python-virtinst

%description -n virt-install
Package includes several command line utilities, including virt-install
(build and install new VMs) and virt-clone (clone an existing virtual
machine).


%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1

%build
%if %{qemu_user}
%define _qemu_user --qemu-user=%{qemu_user}
%endif

%if %{kvm_packages}
%define _kvm_packages --kvm-package-names=%{kvm_packages}
%endif

%if %{preferred_distros}
%define _preferred_distros --preferred-distros=%{preferred_distros}
%endif

%if %{libvirt_packages}
%define _libvirt_packages --libvirt-package-names=%{libvirt_packages}
%endif

%if %{askpass_package}
%define _askpass_package --askpass-package-names=%{askpass_package}
%endif

%if %{stable_defaults}
%define _stable_defaults --stable-defaults
%endif

%if %{default_hvs}
%define _default_hvs --default-hvs %{default_hvs}
%endif

python setup.py configure \
    %{?_qemu_user} \
    %{?_kvm_packages} \
    %{?_libvirt_packages} \
    %{?_askpass_package} \
    %{?_preferred_distros} \
    %{?_stable_defaults} \
    %{?_default_hvs}


%install
python setup.py install -O1 --root=%{buildroot}
%find_lang %{name}

# The conversion script was only added to virt-manager after several
# Fedora cycles of using gsettings. Installing it now could convert old data
# and wipe out recent settings.
rm %{buildroot}%{_datadir}/GConf/gsettings/org.virt-manager.virt-manager.convert


%post
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :
/usr/bin/update-desktop-database &> /dev/null || :


%postun
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
    /usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &> /dev/null || :
fi
/usr/bin/update-desktop-database &> /dev/null || :


%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
/usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &> /dev/null || :


%files
%doc README COPYING NEWS
%{_bindir}/%{name}

%{_mandir}/man1/%{name}.1*

%{_datadir}/%{name}/ui/*.ui
%{_datadir}/%{name}/virt-manager
%{_datadir}/%{name}/virtManager

%{_datadir}/%{name}/icons
%{_datadir}/icons/hicolor/*/apps/*

%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/glib-2.0/schemas/org.virt-manager.virt-manager.gschema.xml


%files common -f %{name}.lang
%dir %{_datadir}/%{name}

%{_datadir}/%{name}/virtcli
%{_datadir}/%{name}/virtconv
%{_datadir}/%{name}/virtinst


%files -n virt-install
%{_mandir}/man1/virt-install.1*
%{_mandir}/man1/virt-clone.1*
%{_mandir}/man1/virt-convert.1*
%{_mandir}/man1/virt-xml.1*

%{_datadir}/%{name}/virt-install
%{_datadir}/%{name}/virt-clone
%{_datadir}/%{name}/virt-convert
%{_datadir}/%{name}/virt-xml

%{_bindir}/virt-install
%{_bindir}/virt-clone
%{_bindir}/virt-convert
%{_bindir}/virt-xml

%changelog
* Thu Sep 5 2019 Nan xiongchao <nanxiongchao@loongson.cn> - 1.2.1-1.12
- sync from gerrit:
- commit 787410c1668eb0ebaadc56bf753f75fb21433469
- Author: yangxiaojuan <yangxiaojuan@loongson.cn>
- Date:   Mon Jun 10 17:41:41 2019 +0800
- Use the host model as the default cpu model
- Change-Id: Id5b7816dde079a891db922f52600e10c6bb6bc96
- 0001-Use-the-host-model-as-the-default-cpu-model.patch

* Thu Jul 11 2019 Nan xiongchao <nanxiongchao@loongson.cn> - 1.2.1-1.11
- sync from gerrit:
- commit 2b5730975993c57c4122620c6151c41bd981e231
- Author: yangxiaojuan <yangxiaojuan@loongson.cn>
- Date:   Tue Jul 9 10:31:46 2019 +0800
- use default disk cache mode
- Change-Id: I17b879496e17ededcf2afd928ecaed061736740b
- 0001-use-default-disk-cache-mode.patch

* Mon Jun 10 2019 Nan xiongchao <nanxiongchao@loongson.cn> - 1.2.1-1.8
- sync from gerrit commit ce98bfa77d29d7fd37f1f056b924b00a87e877b0
- Merge: da830c0 9015bfc
- Author: yangxiaojuan <yangxiaojuan@loongson.cn>
- Date:   Mon Jun 10 14:43:07 2019 +0800
- Merge "Add default usbtablet and usbkeyboard support"
- 0001-Add-default-usbtablet-and-usbkeyboard-support.patch

* Mon Feb 21 2019 yangxiaojuan <yangxiaojuan@loongson.cn> 1.2.1-1.7
- Add 0008-Use-default-scsi-bus-for-CD-ROM-iso-install-and.patch 

* Wed Jan 23 2019 yangxiaojuan <yangxiaojuan@loongson.cn> 1.2.1-1.8
- Add 0006-implent-of-modify-disk-default-cache-mode.patch

* Mon Jan 21 2019 yangxiaojuan <yangxiaojuan@loongson.cn> 1.2.1-1.7
- Add patch:0007-Add-loongson3a-uefi-support-should-used-with-libvirt.patch

* Mon Nov 21 2018 yangxiaojuan <yangxiaojuan@loongson.cn> 1.2.1-1.6
- Add patch:0006-implent-of-modify-disk-default-cache-mode.patch

* Mon Nov 19 2018 yangxiaojuan <yangxiaojuan@loongson.cn> 1.2.1-1.5
- Add patch:0005-modify-disk-default-cache-mode.patch

* Thu Nov 1 2018 nanxiongchao <nanxiongchao@loongson.cn> 1.2.1-1.4
- add-cpu-selection
- add-defaut-kernel-cmd-line
- add-defaults-graphics-device-for-mips
- modify-watchdog-default-action-to-poweroff

* Thu Nov 1 2018 nanxiongchao <nanxiongchao@loongson.cn> 1.2.1-1
- init version 
